# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pymammotion/proto/mctrl_sys.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pymammotion.proto import dev_net_pb2 as pymammotion_dot_proto_dot_dev__net__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!pymammotion/proto/mctrl_sys.proto\x1a\x1fpymammotion/proto/dev_net.proto\"\x1a\n\x08SysBatUp\x12\x0e\n\x06\x62\x61tVal\x18\x01 \x01(\x05\"Z\n\x0cSysWorkState\x12\x13\n\x0b\x64\x65viceState\x18\x01 \x01(\x05\x12\x13\n\x0b\x63hargeState\x18\x02 \x01(\x05\x12\x0e\n\x06\x63mHash\x18\x03 \x01(\x03\x12\x10\n\x08pathHash\x18\x04 \x01(\x03\"5\n\x0eSysSetTimeZone\x12\x11\n\ttimeStamp\x18\x01 \x01(\x05\x12\x10\n\x08timeArea\x18\x02 \x01(\x05\"\x9e\x01\n\x0eSysSetDateTime\x12\x0c\n\x04Year\x18\x01 \x01(\x05\x12\r\n\x05Month\x18\x02 \x01(\x05\x12\x0c\n\x04\x44\x61te\x18\x03 \x01(\x05\x12\x0c\n\x04Week\x18\x04 \x01(\x05\x12\r\n\x05Hours\x18\x05 \x01(\x05\x12\x0f\n\x07Minutes\x18\x06 \x01(\x05\x12\x0f\n\x07Seconds\x18\x07 \x01(\x05\x12\x10\n\x08timeZone\x18\x08 \x01(\x05\x12\x10\n\x08\x64\x61ylight\x18\t \x01(\x05\"V\n\nSysJobPlan\x12\r\n\x05jobId\x18\x01 \x01(\x03\x12\x0f\n\x07jobMode\x18\x02 \x01(\x05\x12\x13\n\x0brainTactics\x18\x03 \x01(\x05\x12\x13\n\x0bknifeHeight\x18\x04 \x01(\x05\"\"\n\rSysDevErrCode\x12\x11\n\terrorCode\x18\x01 \x01(\x05\"!\n\x0cSysBoardType\x12\x11\n\tboardType\x18\x01 \x01(\x05\"5\n\x0cSysSwVersion\x12\x11\n\tboardType\x18\x01 \x01(\x05\x12\x12\n\nversionLen\x18\x02 \x01(\x05\"1\n\rSysDelJobPlan\x12\x10\n\x08\x64\x65viceId\x18\x01 \x01(\t\x12\x0e\n\x06planId\x18\x02 \x01(\t\"\xec\x01\n\x0eSysJobPlanTime\x12\x0e\n\x06planId\x18\x01 \x01(\x03\x12\x16\n\x0estart_job_time\x18\x02 \x01(\x05\x12\x14\n\x0c\x65nd_job_time\x18\x03 \x01(\x05\x12\x13\n\x0btime_in_day\x18\x04 \x01(\x05\x12\x15\n\rjob_plan_mode\x18\x05 \x01(\x05\x12\x17\n\x0fjob_plan_enable\x18\x06 \x01(\x05\x12\x0f\n\x07weekDay\x18\x07 \x03(\x05\x12\x15\n\rtimeInWeekDay\x18\x08 \x03(\x05\x12\x10\n\x08\x65veryDay\x18\t \x01(\x05\x12\x1d\n\x08job_plan\x18\n \x01(\x0b\x32\x0b.SysJobPlan\"k\n\nSysMowInfo\x12\x13\n\x0b\x64\x65viceState\x18\x01 \x01(\x05\x12\x0e\n\x06\x62\x61tVal\x18\x02 \x01(\x05\x12\x13\n\x0bknifeHeight\x18\x03 \x01(\x05\x12\x11\n\tRTKstatus\x18\x04 \x01(\x05\x12\x10\n\x08RTKstars\x18\x05 \x01(\x05\";\n\x0eSysOptiLineAck\x12\x13\n\x0bresponesCmd\x18\x01 \x01(\x05\x12\x14\n\x0c\x63urrentFrame\x18\x02 \x01(\x05\"5\n\nSysCommCmd\x12\n\n\x02rw\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ontext\x18\x03 \x01(\x05\"H\n\x15SysUploadFileProgress\x12\r\n\x05\x62izId\x18\x01 \x01(\t\x12\x0e\n\x06result\x18\x02 \x01(\x05\x12\x10\n\x08progress\x18\x03 \x01(\x05\"\x1f\n\x0cSysErrorCode\x12\x0f\n\x07\x63ode_no\x18\x01 \x01(\x05\"\x1e\n\tSysBorder\x12\x11\n\tborderval\x18\x01 \x01(\x05\"*\n\x10SysPlanJobStatus\x12\x16\n\x0eplanjob_status\x18\x01 \x01(\x05\"=\n\x0fSysKnifeControl\x12\x14\n\x0cknife_status\x18\x01 \x01(\x05\x12\x14\n\x0cknife_height\x18\x02 \x01(\x05\"+\n\x14SysResetSystemStatus\x12\x13\n\x0breset_staus\x18\x01 \x01(\x05\"C\n\x1bSysResetBladeUsedTimeStatus\x12$\n\x1creset_blade_used_time_status\x18\x01 \x01(\x05\"\x8a\x01\n\rTimeCtrlLight\x12\x0f\n\x07operate\x18\x01 \x01(\x05\x12\x0e\n\x06\x65nable\x18\x02 \x01(\x05\x12\x12\n\nstart_hour\x18\x03 \x01(\x05\x12\x11\n\tstart_min\x18\x04 \x01(\x05\x12\x10\n\x08\x65nd_hour\x18\x05 \x01(\x05\x12\x0f\n\x07\x65nd_min\x18\x06 \x01(\x05\x12\x0e\n\x06\x61\x63tion\x18\x07 \x01(\x05\"3\n\x10vision_point_msg\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"\\\n\x15vision_point_info_msg\x12\r\n\x05label\x18\x01 \x01(\x05\x12\x0b\n\x03num\x18\x02 \x01(\x05\x12\'\n\x0cvision_point\x18\x03 \x03(\x0b\x32\x11.vision_point_msg\"\x9a\x01\n\x13vio_to_app_info_msg\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\x0f\n\x07heading\x18\x03 \x01(\x01\x12\x11\n\tvio_state\x18\x04 \x01(\x05\x12\x12\n\nbrightness\x18\x05 \x01(\x05\x12\x1a\n\x12\x64\x65tect_feature_num\x18\x06 \x01(\x05\x12\x19\n\x11track_feature_num\x18\x07 \x01(\x05\"1\n\x14vision_statistic_msg\x12\x0c\n\x04mean\x18\x01 \x01(\x02\x12\x0b\n\x03var\x18\x02 \x01(\x02\"m\n\x19vision_statistic_info_msg\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12\x0b\n\x03num\x18\x02 \x01(\x05\x12\x30\n\x11vision_statistics\x18\x03 \x03(\x0b\x32\x15.vision_statistic_msg\"\xd3\x01\n\x1asystemRapidStateTunnel_msg\x12\x18\n\x10rapid_state_data\x18\x01 \x03(\x03\x12\x31\n\x11vision_point_info\x18\x02 \x03(\x0b\x32\x16.vision_point_info_msg\x12-\n\x0fvio_to_app_info\x18\x03 \x01(\x0b\x32\x14.vio_to_app_info_msg\x12\x39\n\x15vision_statistic_info\x18\x04 \x01(\x0b\x32\x1a.vision_statistic_info_msg\"4\n\x19systemTardStateTunnel_msg\x12\x17\n\x0ftard_state_data\x18\x01 \x03(\x03\".\n\x13systemUpdateBuf_msg\x12\x17\n\x0fupdate_buf_data\x18\x01 \x03(\x03\"\x9e\x01\n\x0fSysOffChipFlash\x12\x16\n\x02op\x18\x01 \x01(\x0e\x32\n.Operation\x12\x16\n\x02id\x18\x02 \x01(\x0e\x32\n.OffPartId\x12\x12\n\nstart_addr\x18\x03 \x01(\r\x12\x0e\n\x06offset\x18\x04 \x01(\r\x12\x0e\n\x06length\x18\x05 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\x12\x0c\n\x04\x63ode\x18\x07 \x01(\x05\x12\x0b\n\x03msg\x18\x08 \x01(\t\"-\n\x14systemTmpCycleTx_msg\x12\x15\n\rcycle_tx_data\x18\x01 \x03(\x03\"%\n\nLoraCfgReq\x12\n\n\x02op\x18\x01 \x01(\x05\x12\x0b\n\x03\x63\x66g\x18\x02 \x01(\t\"F\n\nLoraCfgRsp\x12\x0e\n\x06result\x18\x01 \x01(\x05\x12\n\n\x02op\x18\x02 \x01(\x05\x12\x0b\n\x03\x63\x66g\x18\x03 \x01(\t\x12\x0f\n\x07\x66\x61\x63_cfg\x18\x04 \x01(\x0c\">\n\x0bmod_fw_info\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x10\n\x08identify\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"L\n\x0e\x64\x65vice_fw_info\x12\x0e\n\x06result\x18\x01 \x01(\x05\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x19\n\x03mod\x18\x03 \x03(\x0b\x32\x0c.mod_fw_info\"@\n\x11mow_to_app_info_t\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0b\n\x03\x63md\x18\x02 \x01(\x05\x12\x10\n\x08mow_data\x18\x03 \x03(\x05\"a\n\x1a\x64\x65vice_product_type_info_t\x12\x0e\n\x06result\x18\x01 \x01(\x05\x12\x19\n\x11main_product_type\x18\x02 \x01(\t\x12\x18\n\x10sub_product_type\x18\x03 \x01(\t\"P\n\x0fQCAppTestExcept\x12\x13\n\x0b\x65xcept_type\x18\x01 \x01(\t\x12(\n\nconditions\x18\x02 \x03(\x0b\x32\x14.QCAppTestConditions\"t\n\x13QCAppTestConditions\x12\x11\n\tcond_type\x18\x01 \x01(\t\x12\x0f\n\x07int_val\x18\x02 \x01(\x05\x12\x11\n\tfloat_val\x18\x03 \x01(\x02\x12\x12\n\ndouble_val\x18\x04 \x01(\x01\x12\x12\n\nstring_val\x18\x05 \x01(\t\"\x99\x01\n\x19mow_to_app_qctools_info_t\x12\x1a\n\x04type\x18\x01 \x01(\x0e\x32\x0c.QCAppTestId\x12\x16\n\x0etimeOfDuration\x18\x02 \x01(\x05\x12\x0e\n\x06result\x18\x03 \x01(\x05\x12\x16\n\x0eresult_details\x18\x04 \x01(\t\x12 \n\x06\x65xcept\x18\x05 \x03(\x0b\x32\x10.QCAppTestExcept\"O\n\x16mCtrlSimulationCmdData\x12\x0e\n\x06subCmd\x18\x01 \x01(\x05\x12\x10\n\x08param_id\x18\x02 \x01(\x05\x12\x13\n\x0bparam_value\x18\x03 \x03(\x05\"7\n\x1c\x61pp_to_dev_get_mqtt_config_t\x12\x17\n\x0fget_mqtt_config\x18\x01 \x01(\x05\"H\n\x1c\x64\x65v_to_app_get_mqtt_config_t\x12\x12\n\nrtk_status\x18\x01 \x01(\x05\x12\x14\n\x0crtk_base_num\x18\x02 \x01(\t\"t\n\x19\x61pp_to_dev_set_mqtt_rtk_t\x12$\n\x0cset_rtk_mode\x18\x01 \x01(\x0e\x32\x0e.rtk_used_type\x12\x16\n\x0estop_nrtk_flag\x18\x02 \x01(\x05\x12\x19\n\x11set_nrtk_net_mode\x18\x03 \x01(\x05\"7\n\x19\x64\x65v_to_app_set_mqtt_rtk_t\x12\x1a\n\x12set_rtk_mode_error\x18\x01 \x01(\x05\"\x8f\x01\n\x08rpt_lora\x12\x16\n\x0epair_code_scan\x18\x01 \x01(\x05\x12\x19\n\x11pair_code_channel\x18\x02 \x01(\x05\x12\x17\n\x0fpair_code_locid\x18\x03 \x01(\x05\x12\x17\n\x0fpair_code_netid\x18\x04 \x01(\x05\x12\x1e\n\x16lora_connection_status\x18\x05 \x01(\x05\"\xd4\x01\n\x10mqtt_rtk_connect\x12\"\n\nrtk_switch\x18\x01 \x01(\x0e\x32\x0e.rtk_used_type\x12\x13\n\x0brtk_channel\x18\x02 \x01(\x05\x12\x14\n\x0crtk_base_num\x18\x03 \x01(\t\x12\x10\n\x08latitude\x18\x04 \x01(\x01\x12\x11\n\tlongitude\x18\x05 \x01(\x01\x12\x1f\n\x17nrtk_map_convert_status\x18\x06 \x01(\x05\x12\x15\n\rnrtk_net_mode\x18\x07 \x01(\x05\x12\x14\n\x0cnew_rtk_mode\x18\x08 \x01(\x05\"\x86\x01\n\tpos_score\x12\x13\n\x0brover_score\x18\x01 \x01(\r\x12\x13\n\x0brover_level\x18\x02 \x01(\r\x12\x12\n\nbase_score\x18\x03 \x01(\r\x12\x12\n\nbase_level\x18\x04 \x01(\r\x12\x12\n\nbase_moved\x18\x05 \x01(\r\x12\x13\n\x0b\x62\x61se_moving\x18\x06 \x01(\r\"\xbb\x02\n\x07rpt_rtk\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x11\n\tpos_level\x18\x02 \x01(\x05\x12\x11\n\tgps_stars\x18\x03 \x01(\x05\x12\x0b\n\x03\x61ge\x18\x04 \x01(\x05\x12\x0f\n\x07lat_std\x18\x05 \x01(\x05\x12\x0f\n\x07lon_std\x18\x06 \x01(\x05\x12\x10\n\x08l2_stars\x18\x07 \x01(\x05\x12\x12\n\ndis_status\x18\x08 \x01(\x03\x12\x17\n\x0ftop4_total_mean\x18\t \x01(\x03\x12\x15\n\rco_view_stars\x18\n \x01(\x05\x12\r\n\x05reset\x18\x0b \x01(\x05\x12\x1c\n\tlora_info\x18\x0c \x01(\x0b\x32\t.rpt_lora\x12(\n\rmqtt_rtk_info\x18\r \x01(\x0b\x32\x11.mqtt_rtk_connect\x12\x1e\n\nscore_info\x18\x0e \x01(\x0b\x32\n.pos_score\"\x86\x01\n\x10rpt_dev_location\x12\x12\n\nreal_pos_x\x18\x01 \x01(\x05\x12\x12\n\nreal_pos_y\x18\x02 \x01(\x05\x12\x13\n\x0breal_toward\x18\x03 \x01(\x05\x12\x10\n\x08pos_type\x18\x04 \x01(\x05\x12\x11\n\tzone_hash\x18\x05 \x01(\x03\x12\x10\n\x08\x62ol_hash\x18\x06 \x01(\x03\"4\n\x13vio_survival_info_t\x12\x1d\n\x15vio_survival_distance\x18\x01 \x01(\x02\";\n\x12\x63ollector_status_t\x12%\n\x1d\x63ollector_installation_status\x18\x01 \x01(\x05\"\"\n\x0clock_state_t\x12\x12\n\nlock_state\x18\x01 \x01(\r\"\x8b\x03\n\x0erpt_dev_status\x12\x12\n\nsys_status\x18\x01 \x01(\x05\x12\x14\n\x0c\x63harge_state\x18\x02 \x01(\x05\x12\x13\n\x0b\x62\x61ttery_val\x18\x03 \x01(\x05\x12\x15\n\rsensor_status\x18\x04 \x01(\x05\x12\x13\n\x0blast_status\x18\x05 \x01(\x05\x12\x16\n\x0esys_time_stamp\x18\x06 \x01(\x03\x12\x14\n\x0cvslam_status\x18\x07 \x01(\x05\x12\x1c\n\tmnet_info\x18\x08 \x01(\x0b\x32\t.MnetInfo\x12/\n\x11vio_survival_info\x18\t \x01(\x0b\x32\x14.vio_survival_info_t\x12-\n\x10\x63ollector_status\x18\n \x01(\x0b\x32\x13.collector_status_t\x12!\n\nlock_state\x18\x0b \x01(\x0b\x32\r.lock_state_t\x12\x19\n\x11self_check_status\x18\x0c \x01(\r\x12$\n\x08\x66pv_info\x18\r \x01(\x0b\x32\x12.fpv_to_app_info_t\"-\n\tnet_speed\x12\x10\n\x08\x64ownload\x18\x01 \x01(\r\x12\x0e\n\x06upload\x18\x02 \x01(\r\"\xce\x02\n\x12rpt_connect_status\x12\x14\n\x0c\x63onnect_type\x18\x01 \x01(\x05\x12\x10\n\x08\x62le_rssi\x18\x02 \x01(\x05\x12\x11\n\twifi_rssi\x18\x03 \x01(\x05\x12\x11\n\tlink_type\x18\x04 \x01(\x05\x12\x11\n\tmnet_rssi\x18\x05 \x01(\x05\x12\x11\n\tmnet_inet\x18\x06 \x01(\x05\x12 \n\x08used_net\x18\x07 \x01(\x0e\x32\x0e.net_used_type\x12\x1a\n\x08mnet_cfg\x18\x08 \x01(\x0b\x32\x08.MnetCfg\x12!\n\rdev_net_speed\x18\t \x01(\x0b\x32\n.net_speed\x12\x17\n\x0fiot_wifi_report\x18\n \x01(\x08\x12\x16\n\x0eiot_con_status\x18\x0b \x01(\x05\x12\x17\n\x0fwifi_con_status\x18\x0c \x01(\x05\x12\x19\n\x11wifi_is_available\x18\r \x01(\x05\",\n\x13nav_heading_state_t\x12\x15\n\rheading_state\x18\x01 \x01(\r\"\xfe\x03\n\x08rpt_work\x12\x0c\n\x04plan\x18\x01 \x01(\x05\x12\x11\n\tpath_hash\x18\x02 \x01(\x03\x12\x10\n\x08progress\x18\x03 \x01(\x05\x12\x0c\n\x04\x61rea\x18\x04 \x01(\x05\x12\x0f\n\x07\x62p_info\x18\x05 \x01(\x05\x12\x0f\n\x07\x62p_hash\x18\x06 \x01(\x03\x12\x10\n\x08\x62p_pos_x\x18\x07 \x01(\x05\x12\x10\n\x08\x62p_pos_y\x18\x08 \x01(\x05\x12\x15\n\rreal_path_num\x18\t \x01(\x03\x12\x12\n\npath_pos_x\x18\n \x01(\x05\x12\x12\n\npath_pos_y\x18\x0b \x01(\x05\x12\x14\n\x0cub_zone_hash\x18\x0c \x01(\x03\x12\x14\n\x0cub_path_hash\x18\r \x01(\x03\x12\x15\n\rinit_cfg_hash\x18\x0e \x01(\x03\x12\x15\n\rub_ecode_hash\x18\x0f \x01(\x03\x12\x14\n\x0cnav_run_mode\x18\x10 \x01(\x05\x12\x18\n\x10test_mode_status\x18\x11 \x01(\x03\x12\x15\n\rman_run_speed\x18\x12 \x01(\x05\x12\x17\n\x0fnav_edit_status\x18\x13 \x01(\x05\x12\x14\n\x0cknife_height\x18\x14 \x01(\x05\x12/\n\x11nav_heading_state\x18\x15 \x01(\x0b\x32\x14.nav_heading_state_t\x12\x15\n\rcutter_offset\x18\x16 \x01(\x02\x12\x14\n\x0c\x63utter_width\x18\x17 \x01(\x02\"C\n\nblade_used\x12\x17\n\x0f\x62lade_used_time\x18\x01 \x01(\x05\x12\x1c\n\x14\x62lade_used_warn_time\x18\x02 \x01(\x05\"=\n\x1duser_set_blade_used_warn_time\x12\x1c\n\x14\x62lade_used_warn_time\x18\x01 \x01(\x05\"l\n\x0crpt_maintain\x12\x0f\n\x07mileage\x18\x01 \x01(\x03\x12\x11\n\twork_time\x18\x02 \x01(\x05\x12\x12\n\nbat_cycles\x18\x03 \x01(\x05\x12$\n\x0f\x62lade_used_time\x18\x04 \x01(\x0b\x32\x0b.blade_used\"[\n\x11\x66pv_to_app_info_t\x12\x10\n\x08\x66pv_flag\x18\x01 \x01(\x05\x12\x16\n\x0ewifi_available\x18\x02 \x01(\x05\x12\x1c\n\x14mobile_net_available\x18\x03 \x01(\x05\"\xa4\x01\n\x14rpt_basestation_info\x12\x11\n\tver_major\x18\x01 \x01(\r\x12\x11\n\tver_minor\x18\x02 \x01(\r\x12\x11\n\tver_patch\x18\x03 \x01(\r\x12\x11\n\tver_build\x18\x04 \x01(\r\x12\x1a\n\x12\x62\x61sestation_status\x18\x05 \x01(\r\x12$\n\x1c\x63onnect_status_since_poweron\x18\x06 \x01(\r\"\x8f\x01\n\x0freport_info_cfg\x12\x15\n\x03\x61\x63t\x18\x01 \x01(\x0e\x32\x08.rpt_act\x12\x0f\n\x07timeout\x18\x02 \x01(\x05\x12\x0e\n\x06period\x18\x03 \x01(\x05\x12\x18\n\x10no_change_period\x18\x04 \x01(\x05\x12\r\n\x05\x63ount\x18\x05 \x01(\x05\x12\x1b\n\x03sub\x18\x06 \x03(\x0e\x32\x0e.rpt_info_type\"\xed\x03\n\x10report_info_data\x12$\n\x07\x63onnect\x18\x01 \x01(\x0b\x32\x13.rpt_connect_status\x12\x1c\n\x03\x64\x65v\x18\x02 \x01(\x0b\x32\x0f.rpt_dev_status\x12\x15\n\x03rtk\x18\x03 \x01(\x0b\x32\x08.rpt_rtk\x12$\n\tlocations\x18\x04 \x03(\x0b\x32\x11.rpt_dev_location\x12\x17\n\x04work\x18\x05 \x01(\x0b\x32\t.rpt_work\x12 \n\x07\x66w_info\x18\x06 \x01(\x0b\x32\x0f.device_fw_info\x12\x1f\n\x08maintain\x18\x07 \x01(\x0b\x32\r.rpt_maintain\x12\x31\n\x11vision_point_info\x18\x08 \x03(\x0b\x32\x16.vision_point_info_msg\x12-\n\x0fvio_to_app_info\x18\t \x01(\x0b\x32\x14.vio_to_app_info_msg\x12\x39\n\x15vision_statistic_info\x18\n \x01(\x0b\x32\x1a.vision_statistic_info_msg\x12/\n\x10\x62\x61sestation_info\x18\x0b \x01(\x0b\x32\x15.rpt_basestation_info\x12.\n\x15\x63utter_work_mode_info\x18\x0c \x01(\x0b\x32\x0f.rpt_cutter_rpm\"U\n\x15\x64\x65\x62ug_common_report_t\x12\x0e\n\x06m_name\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x10\n\x08gen_time\x18\x04 \x01(\x03\"W\n\x17\x64\x65\x62ug_errocode_report_t\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\r\n\x05mname\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x10\n\x08gen_time\x18\x04 \x01(\x03\" \n\x0e\x64\x65\x62ug_enable_t\x12\x0e\n\x06\x65nbale\x18\x01 \x01(\x05\"^\n\x17\x64\x65\x62ug_res_cfg_ability_t\x12\x12\n\ntotal_keys\x18\x01 \x01(\x05\x12\x12\n\ncur_key_id\x18\x02 \x01(\x05\x12\x0c\n\x04keys\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\".\n\x10\x64\x65\x62ug_cfg_read_t\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"/\n\x11\x64\x65\x62ug_cfg_write_t\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xa7\x01\n\nmsgbus_pkt\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x13\n\x0btypeCommand\x18\x02 \x01(\x05\x12\x14\n\x0crecvDeviceId\x18\x03 \x01(\x05\x12\x14\n\x0csendDeviceId\x18\x04 \x01(\x05\x12\x12\n\ndataLength\x18\x05 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\x12\x0c\n\x04\x63trl\x18\x07 \x01(\x05\x12\x0c\n\x04\x66lag\x18\x08 \x01(\x05\x12\x0c\n\x04seqs\x18\t \x01(\x05\"\xb1\x01\n\x13response_set_mode_t\x12\x0e\n\x06statue\x18\x01 \x01(\x05\x12\x15\n\rset_work_mode\x18\x02 \x01(\x05\x12\x15\n\rcur_work_mode\x18\x03 \x01(\x05\x12\x17\n\x0fstart_work_time\x18\x04 \x01(\x03\x12\x15\n\rend_work_time\x18\x05 \x01(\x03\x12\x15\n\rinterruptflag\x18\x06 \x01(\x05\x12\x15\n\rcur_work_time\x18\x07 \x01(\x05\"I\n\x0erpt_cutter_rpm\x12\x1b\n\x13\x63urrent_cutter_mode\x18\x01 \x01(\x05\x12\x1a\n\x12\x63urrent_cutter_rpm\x18\x02 \x01(\x05\"\x8d\x02\n\x0c\x64\x65v_statue_t\x12\x12\n\nsys_status\x18\x01 \x01(\x05\x12\x15\n\rcharge_status\x18\x02 \x01(\x05\x12\x0f\n\x07\x62\x61t_val\x18\x03 \x01(\x05\x12\x14\n\x0cwheel_status\x18\x04 \x01(\x05\x12\x13\n\x0bpump_status\x18\x05 \x01(\x05\x12\x11\n\twork_mode\x18\x06 \x01(\x05\x12\r\n\x05model\x18\x07 \x01(\x05\x12\x10\n\x08\x62le_rssi\x18\x08 \x01(\x05\x12\x11\n\twifi_rssi\x18\t \x01(\x05\x12\x1b\n\x13wifi_connect_status\x18\n \x01(\x05\x12\x1a\n\x12iot_connect_status\x18\x0b \x01(\x05\x12\x16\n\x0ewifi_available\x18\x0c \x01(\x05\"2\n\rreport_info_t\x12!\n\ndev_status\x18\x01 \x01(\x0b\x32\r.dev_statue_t\" \n\x0bwork_mode_t\x12\x11\n\twork_mode\x18\x01 \x01(\x05\"Q\n\x0especial_mode_t\x12\x12\n\nstair_mode\x18\x01 \x01(\x05\x12\x14\n\x0cviolent_mode\x18\x02 \x01(\x05\x12\x15\n\rberthing_mode\x18\x03 \x01(\x05\"(\n\x11set_peripherals_t\x12\x13\n\x0b\x62uzz_enable\x18\x01 \x01(\x05\"K\n\x10\x64\x65\x62ug_sun_time_t\x12\x0e\n\x06subCmd\x18\x01 \x01(\x05\x12\x13\n\x0bsunRiseTime\x18\x02 \x01(\x05\x12\x12\n\nsunSetTime\x18\x03 \x01(\x05\"l\n\x12remote_reset_req_t\x12\r\n\x05magic\x18\x01 \x01(\x05\x12\r\n\x05\x62izid\x18\x02 \x01(\x03\x12\x12\n\nreset_mode\x18\x03 \x01(\x05\x12\x13\n\x0b\x66orce_reset\x18\x04 \x01(\x05\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\x03\"S\n\x12remote_reset_rsp_t\x12\r\n\x05magic\x18\x01 \x01(\x05\x12\r\n\x05\x62izid\x18\x02 \x01(\x03\x12\x1f\n\x06result\x18\x03 \x01(\x0e\x32\x0f.Command_Result\"\xb1\x16\n\x07MctlSys\x12\"\n\rtoapp_batinfo\x18\x01 \x01(\x0b\x32\t.SysBatUpH\x00\x12)\n\x10toapp_work_state\x18\x02 \x01(\x0b\x32\r.SysWorkStateH\x00\x12*\n\x0ftodev_time_zone\x18\x03 \x01(\x0b\x32\x0f.SysSetTimeZoneH\x00\x12*\n\x0ftodev_data_time\x18\x04 \x01(\x0b\x32\x0f.SysSetDateTimeH\x00\x12\x1f\n\x08job_plan\x18\x06 \x01(\x0b\x32\x0b.SysJobPlanH\x00\x12(\n\x0etoapp_err_code\x18\x07 \x01(\x0b\x32\x0e.SysDevErrCodeH\x00\x12.\n\x13todev_job_plan_time\x18\n \x01(\x0b\x32\x0f.SysJobPlanTimeH\x00\x12%\n\x0etoapp_mow_info\x18\x0b \x01(\x0b\x32\x0b.SysMowInfoH\x00\x12&\n\x0f\x62idire_comm_cmd\x18\x0c \x01(\x0b\x32\x0b.SysCommCmdH\x00\x12\x16\n\x0cplan_job_del\x18\x0e \x01(\x03H\x00\x12\x1c\n\x06\x62order\x18\x0f \x01(\x0b\x32\n.SysBorderH\x00\x12.\n\x11toapp_plan_status\x18\x12 \x01(\x0b\x32\x11.SysPlanJobStatusH\x00\x12\x34\n\x12toapp_ul_fprogress\x18\x13 \x01(\x0b\x32\x16.SysUploadFileProgressH\x00\x12*\n\x10todev_deljobplan\x18\x14 \x01(\x0b\x32\x0e.SysDelJobPlanH\x00\x12\x1b\n\x11todev_mow_info_up\x18\x15 \x01(\x05H\x00\x12,\n\x10todev_knife_ctrl\x18\x16 \x01(\x0b\x32\x10.SysKnifeControlH\x00\x12\x1c\n\x12todev_reset_system\x18\x17 \x01(\x05H\x00\x12:\n\x19todev_reset_system_status\x18\x18 \x01(\x0b\x32\x15.SysResetSystemStatusH\x00\x12=\n\x16systemRapidStateTunnel\x18\x19 \x01(\x0b\x32\x1b.systemRapidStateTunnel_msgH\x00\x12;\n\x15systemTardStateTunnel\x18\x1a \x01(\x0b\x32\x1a.systemTardStateTunnel_msgH\x00\x12/\n\x0fsystemUpdateBuf\x18\x1b \x01(\x0b\x32\x14.systemUpdateBuf_msgH\x00\x12/\n\x15todev_time_ctrl_light\x18\x1c \x01(\x0b\x32\x0e.TimeCtrlLightH\x00\x12\x31\n\x10systemTmpCycleTx\x18\x1d \x01(\x0b\x32\x15.systemTmpCycleTx_msgH\x00\x12\x30\n\x14todev_off_chip_flash\x18\x1e \x01(\x0b\x32\x10.SysOffChipFlashH\x00\x12\x1f\n\x15todev_get_dev_fw_info\x18\x1f \x01(\x05H\x00\x12,\n\x11toapp_dev_fw_info\x18  \x01(\x0b\x32\x0f.device_fw_infoH\x00\x12)\n\x12todev_lora_cfg_req\x18! \x01(\x0b\x32\x0b.LoraCfgReqH\x00\x12)\n\x12toapp_lora_cfg_rsp\x18\" \x01(\x0b\x32\x0b.LoraCfgRspH\x00\x12-\n\x0fmow_to_app_info\x18# \x01(\x0b\x32\x12.mow_to_app_info_tH\x00\x12?\n\x18\x64\x65vice_product_type_info\x18$ \x01(\x0b\x32\x1b.device_product_type_info_tH\x00\x12=\n\x17mow_to_app_qctools_info\x18% \x01(\x0b\x32\x1a.mow_to_app_qctools_info_tH\x00\x12,\n\x10todev_report_cfg\x18& \x01(\x0b\x32\x10.report_info_cfgH\x00\x12.\n\x11toapp_report_data\x18\' \x01(\x0b\x32\x11.report_info_dataH\x00\x12\x31\n\x0esimulation_cmd\x18* \x01(\x0b\x32\x17.mCtrlSimulationCmdDataH\x00\x12G\n\x1e\x61pp_to_dev_get_mqtt_config_msg\x18+ \x01(\x0b\x32\x1d.app_to_dev_get_mqtt_config_tH\x00\x12G\n\x1e\x64\x65v_to_app_get_mqtt_config_msg\x18, \x01(\x0b\x32\x1d.dev_to_app_get_mqtt_config_tH\x00\x12\x41\n\x1b\x61pp_to_dev_set_mqtt_rtk_msg\x18- \x01(\x0b\x32\x1a.app_to_dev_set_mqtt_rtk_tH\x00\x12\x41\n\x1b\x64\x65v_to_app_set_mqtt_rtk_msg\x18. \x01(\x0b\x32\x1a.dev_to_app_set_mqtt_rtk_tH\x00\x12%\n\x1btodev_reset_blade_used_time\x18/ \x01(\x05H\x00\x12J\n\"todev_reset_blade_used_time_status\x18\x30 \x01(\x0b\x32\x1c.SysResetBladeUsedTimeStatusH\x00\x12#\n\x19todev_factor_reset_system\x18\x31 \x01(\x05H\x00\x12>\n\x14\x62lade_used_warn_time\x18\x32 \x01(\x0b\x32\x1e.user_set_blade_used_warn_timeH\x00\x12\x35\n\x13\x64\x65\x62ug_common_report\x18\x33 \x01(\x0b\x32\x16.debug_common_report_tH\x00\x12\x39\n\x15\x64\x65\x62ug_errocode_report\x18\x34 \x01(\x0b\x32\x18.debug_errocode_report_tH\x00\x12\'\n\x0c\x64\x65\x62ug_enable\x18\x35 \x01(\x0b\x32\x0f.debug_enable_tH\x00\x12+\n\x0e\x64\x65\x62ug_cfg_read\x18\x36 \x01(\x0b\x32\x11.debug_cfg_read_tH\x00\x12-\n\x0f\x64\x65\x62ug_cfg_write\x18\x37 \x01(\x0b\x32\x12.debug_cfg_write_tH\x00\x12\x39\n\x15\x64\x65\x62ug_res_cfg_ability\x18\x38 \x01(\x0b\x32\x18.debug_res_cfg_ability_tH\x00\x12$\n\rto_dev_msgbus\x18\x39 \x01(\x0b\x32\x0b.msgbus_pktH\x00\x12$\n\rto_app_msgbus\x18: \x01(\x0b\x32\x0b.msgbus_pktH\x00\x12\x31\n\x11response_set_mode\x18; \x01(\x0b\x32\x14.response_set_mode_tH\x00\x12%\n\x0breport_info\x18< \x01(\x0b\x32\x0e.report_info_tH\x00\x12%\n\rset_work_mode\x18= \x01(\x0b\x32\x0c.work_mode_tH\x00\x12+\n\x10set_special_mode\x18> \x01(\x0b\x32\x0f.special_mode_tH\x00\x12-\n\x0fset_peripherals\x18? \x01(\x0b\x32\x12.set_peripherals_tH\x00\x12\x30\n\x13to_dev_set_sun_time\x18@ \x01(\x0b\x32\x11.debug_sun_time_tH\x00\x12\x32\n\x13to_dev_remote_reset\x18\x41 \x01(\x0b\x32\x13.remote_reset_req_tH\x00\x12\x32\n\x13to_app_remote_reset\x18\x42 \x01(\x0b\x32\x13.remote_reset_rsp_tH\x00\x12.\n\x13\x63urrent_cutter_mode\x18\x43 \x01(\x0b\x32\x0f.rpt_cutter_rpmH\x00\x42\x0b\n\tSubSysMsg*+\n\tOperation\x12\t\n\x05WRITE\x10\x00\x12\x08\n\x04READ\x10\x01\x12\t\n\x05\x45RASE\x10\x02*\x8d\x02\n\tOffPartId\x12\x13\n\x0fOFF_PART_DL_IMG\x10\x00\x12\x19\n\x15OFF_PART_UPDINFO_BACK\x10\x01\x12\x14\n\x10OFF_PART_UPDINFO\x10\x02\x12\x13\n\x0fOFF_PART_NAKEDB\x10\x03\x12\x14\n\x10OFF_PART_FLASHDB\x10\x04\x12\x18\n\x14OFF_PART_UPD_APP_IMG\x10\x05\x12\x18\n\x14OFF_PART_UPD_BMS_IMG\x10\x06\x12\x18\n\x14OFF_PART_UPD_TMP_IMG\x10\x07\x12\x15\n\x11OFF_PART_DEV_INFO\x10\x08\x12\x18\n\x14OFF_PART_NAKEDB_BACK\x10\t\x12\x10\n\x0cOFF_PART_MAX\x10\n*\xe5\x08\n\x0bQCAppTestId\x12!\n\x1dQC_APP_ITEM_ON_CHARGESATSTION\x10\x00\x12\x1a\n\x16QC_APP_TEST_X3_SPEAKER\x10\x01\x12)\n%QC_APP_TEST_STATIC_OBSTACLE_DETECTION\x10\x02\x12\"\n\x1eQC_APP_TEST_CHARGESTATION_TEMP\x10\x03\x12\x13\n\x0fQC_APP_ITEM_KEY\x10\x04\x12 \n\x1cQC_APP_TEST_BUMPER_FRONTLEFT\x10\x05\x12!\n\x1dQC_APP_TEST_BUMPER_FRONTRIGHT\x10\x06\x12\x14\n\x10QC_APP_TEST_STOP\x10\x07\x12\x16\n\x12QC_APP_TEST_UNLOCK\x10\x08\x12\x14\n\x10QC_APP_TEST_BUZZ\x10\t\x12\x14\n\x10QC_APP_TEST_LIFT\x10\n\x12\x16\n\x12QC_APP_ITEM_SENEOR\x10\x0b\x12\x19\n\x15QC_APP_TEST_ROLL_LEFT\x10\x0c\x12\x1a\n\x16QC_APP_TEST_ROLL_RIGHT\x10\r\x12\x1d\n\x19QC_APP_TEST_ULTRA_UNCOVER\x10\x0e\x12\x1c\n\x18QC_APP_TEST_ULTRA0_COVER\x10\x0f\x12\x1c\n\x18QC_APP_TEST_ULTRA1_COVER\x10\x10\x12\x1c\n\x18QC_APP_TEST_ULTRA2_COVER\x10\x11\x12\x14\n\x10QC_APP_TEST_RAIN\x10\x12\x12\x12\n\x0eQC_APP_ITEM_SQ\x10\x13\x12\x18\n\x14QC_APP_TEST_BLE_RSSI\x10\x14\x12 \n\x1cQC_APP_TEST_SATELLITES_ROVER\x10\x15\x12)\n%QC_APP_TEST_SATELLITES_REF_STATION_L1\x10\x16\x12)\n%QC_APP_TEST_SATELLITES_REF_STATION_L2\x10\x17\x12&\n\"QC_APP_TEST_SATELLITES_COMMON_VIEW\x10\x18\x12\x19\n\x15QC_APP_TEST_CNO_ROVER\x10\x19\x12\x1f\n\x1bQC_APP_TEST_CNO_REF_STATION\x10\x1a\x12\'\n#QC_APP_TEST_REF_STATION_LINK_STATUS\x10\x1b\x12\x1e\n\x1aQC_APP_TEST_LOCATION_STATE\x10\x1c\x12\x1d\n\x19QC_APP_TEST_CHARGE_STATUS\x10\x1d\x12\x1e\n\x1aQC_APP_TEST_PPS_EXTI_COUNT\x10\x1e\x12\x18\n\x14QC_APP_TEST_SAFE_KEY\x10\x32\x12\x19\n\x15QC_APP_TEST_LORA_RSSI\x10<\x12\x1a\n\x16QC_APP_TEST_WIPER_TEST\x10P\x12\x1d\n\x19QC_APP_TEST_HEADLAMP_TEST\x10Q\x12\x1f\n\x1bQC_APP_TEST_COMPLETE_SIGNAL\x10\x63\x12\x13\n\x0fQC_APP_TEST_MAX\x10\x64*L\n\rrtk_used_type\x12\x11\n\rRTK_USED_LORA\x10\x00\x12\x15\n\x11RTK_USED_INTERNET\x10\x01\x12\x11\n\rRTK_USED_NRTK\x10\x02*W\n\rnet_used_type\x12\x16\n\x12NET_USED_TYPE_NONE\x10\x00\x12\x16\n\x12NET_USED_TYPE_WIFI\x10\x01\x12\x16\n\x12NET_USED_TYPE_MNET\x10\x02*\xee\x01\n\rrpt_info_type\x12\x0f\n\x0bRIT_CONNECT\x10\x00\x12\x0f\n\x0bRIT_DEV_STA\x10\x01\x12\x0b\n\x07RIT_RTK\x10\x02\x12\x11\n\rRIT_DEV_LOCAL\x10\x03\x12\x0c\n\x08RIT_WORK\x10\x04\x12\x0f\n\x0bRIT_FW_INFO\x10\x05\x12\x10\n\x0cRIT_MAINTAIN\x10\x06\x12\x14\n\x10RIT_VISION_POINT\x10\x07\x12\x0b\n\x07RIT_VIO\x10\x08\x12\x18\n\x14RIT_VISION_STATISTIC\x10\t\x12\x18\n\x14RIT_BASESTATION_INFO\x10\n\x12\x13\n\x0fRIT_CUTTER_INFO\x10\x0b*4\n\x07rpt_act\x12\r\n\tRPT_START\x10\x00\x12\x0c\n\x08RPT_STOP\x10\x01\x12\x0c\n\x08RPT_KEEP\x10\x02*R\n\x0e\x43ommand_Result\x12\t\n\x05RS_OK\x10\x00\x12\x11\n\rRS_FAIL_MAGIC\x10\x01\x12\x0f\n\x0bRS_FAIL_OTA\x10\x02\x12\x11\n\rRS_FAIL_SLOPE\x10\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pymammotion.proto.mctrl_sys_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _OPERATION._serialized_start=11827
  _OPERATION._serialized_end=11870
  _OFFPARTID._serialized_start=11873
  _OFFPARTID._serialized_end=12142
  _QCAPPTESTID._serialized_start=12145
  _QCAPPTESTID._serialized_end=13270
  _RTK_USED_TYPE._serialized_start=13272
  _RTK_USED_TYPE._serialized_end=13348
  _NET_USED_TYPE._serialized_start=13350
  _NET_USED_TYPE._serialized_end=13437
  _RPT_INFO_TYPE._serialized_start=13440
  _RPT_INFO_TYPE._serialized_end=13678
  _RPT_ACT._serialized_start=13680
  _RPT_ACT._serialized_end=13732
  _COMMAND_RESULT._serialized_start=13734
  _COMMAND_RESULT._serialized_end=13816
  _SYSBATUP._serialized_start=70
  _SYSBATUP._serialized_end=96
  _SYSWORKSTATE._serialized_start=98
  _SYSWORKSTATE._serialized_end=188
  _SYSSETTIMEZONE._serialized_start=190
  _SYSSETTIMEZONE._serialized_end=243
  _SYSSETDATETIME._serialized_start=246
  _SYSSETDATETIME._serialized_end=404
  _SYSJOBPLAN._serialized_start=406
  _SYSJOBPLAN._serialized_end=492
  _SYSDEVERRCODE._serialized_start=494
  _SYSDEVERRCODE._serialized_end=528
  _SYSBOARDTYPE._serialized_start=530
  _SYSBOARDTYPE._serialized_end=563
  _SYSSWVERSION._serialized_start=565
  _SYSSWVERSION._serialized_end=618
  _SYSDELJOBPLAN._serialized_start=620
  _SYSDELJOBPLAN._serialized_end=669
  _SYSJOBPLANTIME._serialized_start=672
  _SYSJOBPLANTIME._serialized_end=908
  _SYSMOWINFO._serialized_start=910
  _SYSMOWINFO._serialized_end=1017
  _SYSOPTILINEACK._serialized_start=1019
  _SYSOPTILINEACK._serialized_end=1078
  _SYSCOMMCMD._serialized_start=1080
  _SYSCOMMCMD._serialized_end=1133
  _SYSUPLOADFILEPROGRESS._serialized_start=1135
  _SYSUPLOADFILEPROGRESS._serialized_end=1207
  _SYSERRORCODE._serialized_start=1209
  _SYSERRORCODE._serialized_end=1240
  _SYSBORDER._serialized_start=1242
  _SYSBORDER._serialized_end=1272
  _SYSPLANJOBSTATUS._serialized_start=1274
  _SYSPLANJOBSTATUS._serialized_end=1316
  _SYSKNIFECONTROL._serialized_start=1318
  _SYSKNIFECONTROL._serialized_end=1379
  _SYSRESETSYSTEMSTATUS._serialized_start=1381
  _SYSRESETSYSTEMSTATUS._serialized_end=1424
  _SYSRESETBLADEUSEDTIMESTATUS._serialized_start=1426
  _SYSRESETBLADEUSEDTIMESTATUS._serialized_end=1493
  _TIMECTRLLIGHT._serialized_start=1496
  _TIMECTRLLIGHT._serialized_end=1634
  _VISION_POINT_MSG._serialized_start=1636
  _VISION_POINT_MSG._serialized_end=1687
  _VISION_POINT_INFO_MSG._serialized_start=1689
  _VISION_POINT_INFO_MSG._serialized_end=1781
  _VIO_TO_APP_INFO_MSG._serialized_start=1784
  _VIO_TO_APP_INFO_MSG._serialized_end=1938
  _VISION_STATISTIC_MSG._serialized_start=1940
  _VISION_STATISTIC_MSG._serialized_end=1989
  _VISION_STATISTIC_INFO_MSG._serialized_start=1991
  _VISION_STATISTIC_INFO_MSG._serialized_end=2100
  _SYSTEMRAPIDSTATETUNNEL_MSG._serialized_start=2103
  _SYSTEMRAPIDSTATETUNNEL_MSG._serialized_end=2314
  _SYSTEMTARDSTATETUNNEL_MSG._serialized_start=2316
  _SYSTEMTARDSTATETUNNEL_MSG._serialized_end=2368
  _SYSTEMUPDATEBUF_MSG._serialized_start=2370
  _SYSTEMUPDATEBUF_MSG._serialized_end=2416
  _SYSOFFCHIPFLASH._serialized_start=2419
  _SYSOFFCHIPFLASH._serialized_end=2577
  _SYSTEMTMPCYCLETX_MSG._serialized_start=2579
  _SYSTEMTMPCYCLETX_MSG._serialized_end=2624
  _LORACFGREQ._serialized_start=2626
  _LORACFGREQ._serialized_end=2663
  _LORACFGRSP._serialized_start=2665
  _LORACFGRSP._serialized_end=2735
  _MOD_FW_INFO._serialized_start=2737
  _MOD_FW_INFO._serialized_end=2799
  _DEVICE_FW_INFO._serialized_start=2801
  _DEVICE_FW_INFO._serialized_end=2877
  _MOW_TO_APP_INFO_T._serialized_start=2879
  _MOW_TO_APP_INFO_T._serialized_end=2943
  _DEVICE_PRODUCT_TYPE_INFO_T._serialized_start=2945
  _DEVICE_PRODUCT_TYPE_INFO_T._serialized_end=3042
  _QCAPPTESTEXCEPT._serialized_start=3044
  _QCAPPTESTEXCEPT._serialized_end=3124
  _QCAPPTESTCONDITIONS._serialized_start=3126
  _QCAPPTESTCONDITIONS._serialized_end=3242
  _MOW_TO_APP_QCTOOLS_INFO_T._serialized_start=3245
  _MOW_TO_APP_QCTOOLS_INFO_T._serialized_end=3398
  _MCTRLSIMULATIONCMDDATA._serialized_start=3400
  _MCTRLSIMULATIONCMDDATA._serialized_end=3479
  _APP_TO_DEV_GET_MQTT_CONFIG_T._serialized_start=3481
  _APP_TO_DEV_GET_MQTT_CONFIG_T._serialized_end=3536
  _DEV_TO_APP_GET_MQTT_CONFIG_T._serialized_start=3538
  _DEV_TO_APP_GET_MQTT_CONFIG_T._serialized_end=3610
  _APP_TO_DEV_SET_MQTT_RTK_T._serialized_start=3612
  _APP_TO_DEV_SET_MQTT_RTK_T._serialized_end=3728
  _DEV_TO_APP_SET_MQTT_RTK_T._serialized_start=3730
  _DEV_TO_APP_SET_MQTT_RTK_T._serialized_end=3785
  _RPT_LORA._serialized_start=3788
  _RPT_LORA._serialized_end=3931
  _MQTT_RTK_CONNECT._serialized_start=3934
  _MQTT_RTK_CONNECT._serialized_end=4146
  _POS_SCORE._serialized_start=4149
  _POS_SCORE._serialized_end=4283
  _RPT_RTK._serialized_start=4286
  _RPT_RTK._serialized_end=4601
  _RPT_DEV_LOCATION._serialized_start=4604
  _RPT_DEV_LOCATION._serialized_end=4738
  _VIO_SURVIVAL_INFO_T._serialized_start=4740
  _VIO_SURVIVAL_INFO_T._serialized_end=4792
  _COLLECTOR_STATUS_T._serialized_start=4794
  _COLLECTOR_STATUS_T._serialized_end=4853
  _LOCK_STATE_T._serialized_start=4855
  _LOCK_STATE_T._serialized_end=4889
  _RPT_DEV_STATUS._serialized_start=4892
  _RPT_DEV_STATUS._serialized_end=5287
  _NET_SPEED._serialized_start=5289
  _NET_SPEED._serialized_end=5334
  _RPT_CONNECT_STATUS._serialized_start=5337
  _RPT_CONNECT_STATUS._serialized_end=5671
  _NAV_HEADING_STATE_T._serialized_start=5673
  _NAV_HEADING_STATE_T._serialized_end=5717
  _RPT_WORK._serialized_start=5720
  _RPT_WORK._serialized_end=6230
  _BLADE_USED._serialized_start=6232
  _BLADE_USED._serialized_end=6299
  _USER_SET_BLADE_USED_WARN_TIME._serialized_start=6301
  _USER_SET_BLADE_USED_WARN_TIME._serialized_end=6362
  _RPT_MAINTAIN._serialized_start=6364
  _RPT_MAINTAIN._serialized_end=6472
  _FPV_TO_APP_INFO_T._serialized_start=6474
  _FPV_TO_APP_INFO_T._serialized_end=6565
  _RPT_BASESTATION_INFO._serialized_start=6568
  _RPT_BASESTATION_INFO._serialized_end=6732
  _REPORT_INFO_CFG._serialized_start=6735
  _REPORT_INFO_CFG._serialized_end=6878
  _REPORT_INFO_DATA._serialized_start=6881
  _REPORT_INFO_DATA._serialized_end=7374
  _DEBUG_COMMON_REPORT_T._serialized_start=7376
  _DEBUG_COMMON_REPORT_T._serialized_end=7461
  _DEBUG_ERROCODE_REPORT_T._serialized_start=7463
  _DEBUG_ERROCODE_REPORT_T._serialized_end=7550
  _DEBUG_ENABLE_T._serialized_start=7552
  _DEBUG_ENABLE_T._serialized_end=7584
  _DEBUG_RES_CFG_ABILITY_T._serialized_start=7586
  _DEBUG_RES_CFG_ABILITY_T._serialized_end=7680
  _DEBUG_CFG_READ_T._serialized_start=7682
  _DEBUG_CFG_READ_T._serialized_end=7728
  _DEBUG_CFG_WRITE_T._serialized_start=7730
  _DEBUG_CFG_WRITE_T._serialized_end=7777
  _MSGBUS_PKT._serialized_start=7780
  _MSGBUS_PKT._serialized_end=7947
  _RESPONSE_SET_MODE_T._serialized_start=7950
  _RESPONSE_SET_MODE_T._serialized_end=8127
  _RPT_CUTTER_RPM._serialized_start=8129
  _RPT_CUTTER_RPM._serialized_end=8202
  _DEV_STATUE_T._serialized_start=8205
  _DEV_STATUE_T._serialized_end=8474
  _REPORT_INFO_T._serialized_start=8476
  _REPORT_INFO_T._serialized_end=8526
  _WORK_MODE_T._serialized_start=8528
  _WORK_MODE_T._serialized_end=8560
  _SPECIAL_MODE_T._serialized_start=8562
  _SPECIAL_MODE_T._serialized_end=8643
  _SET_PERIPHERALS_T._serialized_start=8645
  _SET_PERIPHERALS_T._serialized_end=8685
  _DEBUG_SUN_TIME_T._serialized_start=8687
  _DEBUG_SUN_TIME_T._serialized_end=8762
  _REMOTE_RESET_REQ_T._serialized_start=8764
  _REMOTE_RESET_REQ_T._serialized_end=8872
  _REMOTE_RESET_RSP_T._serialized_start=8874
  _REMOTE_RESET_RSP_T._serialized_end=8957
  _MCTLSYS._serialized_start=8960
  _MCTLSYS._serialized_end=11825
# @@protoc_insertion_point(module_scope)
